/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */

package isql;

/**
 * A key defining a column in the result set, using the table name and the column name
 * @author SHZ Oct 4, 2007
 */
public class ColumnKey  implements Comparable<ColumnKey>
{

	/**
	 * The name of the table containing the column
	 */
	private String tableName;
	/**
	 * The name of the column
	 */
	private String columnName;

	/**
	 * @return the columnName
	 */
	public String getColumnName()
	{
		return columnName;
	}

	/**
	 * @return the tableName
	 */
	public String getTableName()
	{
		return tableName;
	}

	/* (non-Javadoc)
	 * @see java.lang.Comparable#compareTo(java.lang.Object)
	 */
	public int compareTo(ColumnKey o)
	{
		int tableDiff = tableName.compareTo(o.tableName);
		if(tableDiff != 0)
			return tableDiff;
		return columnName.compareTo(o.columnName);
	}

	/**
	 * Constructor
	 * @param tableName the table name 
	 * @param columnName the column name
	 */
	public ColumnKey(String tableName, String columnName)
	{
		this.tableName = tableName;
		this.columnName = columnName;
	}
	
	@Override
	public String toString()
	{
		return tableName+"."+columnName;
	}
	
	/**
	 * Builds a ColumnKey object from a text
	 * @param s the text in form of <table name>.<column name>
	 * @return the ColumnKey object
	 */
	public static ColumnKey fromString(String s)
	{
		String[] arrSplit = s.split("\\.");
		return new ColumnKey(arrSplit[0], arrSplit[1]);
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((columnName == null) ? 0 : columnName.hashCode());
		result = prime * result
				+ ((tableName == null) ? 0 : tableName.hashCode());
		return result;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		final ColumnKey other = (ColumnKey) obj;
		if (columnName == null)
		{
			if (other.columnName != null)
				return false;
		}
		else if (!columnName.equals(other.columnName))
			return false;
		if (tableName == null)
		{
			if (other.tableName != null)
				return false;
		}
		else if (!tableName.equals(other.tableName))
			return false;
		return true;
	}

}