/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql;

import isql.array.Array;

import java.util.Collection;
import java.util.Map;
import java.util.Set;
import java.util.Map.Entry;

/**
 * The columns of the result set:
 * each column is an array. All columns are mapped by the column key
 * @author SHZ Nov 14, 2007
 */
public class ColumnValues
{
	/**
	 * The map column key -> column values
	 */
	private Map<ColumnKey, Array> mapValuesByColumn;
	
	
	/**
	 * Constuctor
	 * @param mapValuesByColumn map [column identifier] -> [column content]
	 * @throws ISQLException 
	 */
	public ColumnValues(Map<ColumnKey, Array> mapValuesByColumn)
	{
		this.mapValuesByColumn = mapValuesByColumn;
	}



	/**
	 * Returns the columns with their ids
	 * @return the content of the map column identifier -> column content
	 * @see java.util.Map#entrySet()
	 */
	public Set<Entry<ColumnKey, Array>> entrySet()
	{
		return mapValuesByColumn.entrySet();
	}


	/**
	 * Returns the identifiers of the columns
	 * @return the columns identifiers
	 * @see java.util.Map#keySet()
	 */
	public Set<ColumnKey> keySet()
	{
		return mapValuesByColumn.keySet();
	}


	/**
	 * Returns the columns contents (arrays)
	 * @return the arrays of all columns in the result set
	 * @see java.util.Map#values()
	 */
	public Collection<Array> values()
	{
		return mapValuesByColumn.values();
	}


	/**
	 * Returns the array of a column
	 * @param key the column identifier
	 * @return the array contained in the column
	 * @see java.util.Map#get(java.lang.Object)
	 */
	public Array get(ColumnKey key)
	{
		return mapValuesByColumn.get(key);
	}



	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		StringBuilder b = new StringBuilder();
		b.append("[COLUMNVALUES");
		for(Map.Entry<ColumnKey, Array> entry : mapValuesByColumn.entrySet())
		{
			ColumnKey key = entry.getKey();
			Array values = entry.getValue();
			b.append("Column Key: ").append(key);
			b.append("Array: ").append(values.toString());
		}
		b.append(']');
		return b.toString();
	}
}
