/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql;

import isql.array.Array;

import java.util.Map;

/**
 * The column values, together with the number of rows in the result set.
 * It can be tricky to find the number of rows, because what we have is a set of arrays, one for 
 * each column. 
 * If the array have different size what we do? Well, it turns out that we cannot have
 * this condition at this point, so if it happens something is wrong
 * @author SHZ Nov 14, 2007
 */
public class ColumnValuesWithRowsNumber extends ColumnValues
{
	/**
	 * the number of rows in the result set
	 */
	private int numberOfRows;
	/**
	 * @param mapValuesByColumn
	 * @throws ISQLException 
	 */
	public ColumnValuesWithRowsNumber(Map<ColumnKey, Array> mapValuesByColumn) throws ISQLException
	{
		super(mapValuesByColumn);
		buildNumberOfRows();
	}
	/**
	 * Returns the number of rows of the result of a select query.
	 * In the same time, checks that the number of rows is the same for all the columns
	 * @return
	 * @throws ISQLException
	 */
	private void buildNumberOfRows() throws ISQLException
	{
		Integer size = null;
		for(Map.Entry<ColumnKey, Array> entry: entrySet())
		{
			Array array = entry.getValue();
			if(size == null)
				size = Integer.valueOf(array.getSize());
			else if( array.getSize() != size.intValue())
				throw new ISQLException("the size of the array of the result column "+entry.getKey()+" ("+array.getSize()+") is not the same as the others ("+size+")");
		}
		numberOfRows = size.intValue();
	}
	/**
	 * @return the numberOfRows
	 */
	public int getNumberOfRows()
	{
		return numberOfRows;
	}
	
}
