/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */

package isql;

import isql.predicate.WhereView;

/**
 * a predicate is used in the WHERE clause to verify which 
 * rows will be considered by the SELECT expression
 * @author SHZ Sep 27, 2007
 */
public interface IPredicate
{
	/**
	 * Returns, for each involved column, the indices (possibly repeated) of the table rows
	 * that are connected by the predicate. 
	 * In practice it returns a view that consists of the table rows of the involved tables
	 * put together depending by the predicate.
	 * For example a C1 = C2 operator will put together all the table rows for which the
	 * columns C1 and C2 are equal, and discard the others 
	 * @return map table name -> indices of the rows that the predicate connects (possibly repeated).
	 * @throws ISQLException
	 */
	public WhereView apply() throws ISQLException;
}
