/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql;

import java.util.ArrayList;
import java.util.List;

import org.antlr.runtime.RecognitionException;
import org.antlr.runtime.TokenStream;

/**
 * extends ISQLSelectParser (which is generated by ANTLR) to log all the errors
 * reported by ANTLR when parsing the SQL query.
 * Otherwise these errors would be lost
 * @author SHZ Nov 8, 2007
 */
public class ISQLSelectParserWithErrors extends ISQLSelectParser
{
	/**
	 * The errors (they are actually exceptions) reported by ANTLR
	 */
	private List<RecognitionException> lstException = new ArrayList<RecognitionException>();
	/**
	 * Wraps the constructor of ISQLSelectParser
	 * @param input
	 */
	public ISQLSelectParserWithErrors(TokenStream input)
	{
		super(input);
	}

	/* (non-Javadoc)
	 * @see org.antlr.runtime.BaseRecognizer#reportError(org.antlr.runtime.RecognitionException)
	 */
	@Override
	public void reportError(RecognitionException ex)
	{
		lstException.add(ex);
	}

	/**
	 * Returns the error, so that they can be showed to the user
	 * @return the list of errors/exceptions
	 */
	public List<RecognitionException> getExceptions()
	{
		return lstException;
	}
	

}
