/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql;

import isql.array.Array;
import isql.test.JUnitMatrices;
import isql.util.ArrayBuilder;
import isql.util.SystemLogger;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

import org.junit.Test;

/**
 * @author SHZ Nov 15, 2007
 *
 */
public class OrderByTest
{

	/**
	 * Test method for {@link isql.OrderBy#applyOrderBy(java.util.List, isql.ColumnValuesWithRowsNumber)}.
	 * @throws ISQLException 
	 */
	@Test
	public void testApplyOrderBy() throws ISQLException
	{
		OrderBy orderBy = new OrderBy(new SystemLogger());
		List<ISQLSelectParser.OrderBy> lstOrderBy = Arrays.asList(new ISQLSelectParser.OrderBy[] { new ISQLSelectParser.OrderBy(new ISQLSelectParser.TableColumn("test", "ticker")) });
		Map<ColumnKey, Array> mapValuesBefore = new TreeMap<ColumnKey, Array>();
		ColumnKey colKeyTicker = ColumnKey.fromString("test.ticker");
		mapValuesBefore.put(colKeyTicker, new Array(new String[] { "ENOYR-08", "ENOW43-08", "ENOMSEP-08" }, ColumnType.TEXT ));
		ColumnKey colKeyFix = ColumnKey.fromString("test.fix");
		mapValuesBefore.put(colKeyFix, new Array(ArrayBuilder.convertToBig(ColumnType.NUMERIC, new double[] {10, 20, 30}), ColumnType.NUMERIC));

		ColumnValuesWithRowsNumber valuesAfter = orderBy.applyOrderBy(lstOrderBy, new ColumnValuesWithRowsNumber(mapValuesBefore));
		String[] arrTickerAfter = (String[]) valuesAfter.get(colKeyTicker).getArray();
		Double[] arrFixAfter = (Double[]) valuesAfter.get(colKeyFix).getArray();
		JUnitMatrices.assertEquals(arrTickerAfter, new String[] { "ENOMSEP-08", "ENOW43-08", "ENOYR-08" });
		JUnitMatrices.assertEquals(arrFixAfter, ArrayBuilder.convertToBig(ColumnType.NUMERIC, new double[] {30, 20, 10}));
	}

}
