/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.builder;

import isql.IComparison;
import isql.ISQLException;
import isql.comparison.Different;
import isql.comparison.Equal;
import isql.comparison.Greater;
import isql.comparison.GreaterOrEqual;
import isql.comparison.Less;
import isql.comparison.LessOrEqual;

/**
 * @author SHZ Oct 25, 2007
 *
 */
public class ComparisonBuilder
{
	/**
	 * Builds a class that contains the algorithm to handle a specific comparison operator (=, <>, <, >...)
	 * @param operator the textual operator ("=", "<>" ...)
	 * @return an instance of the algorithm class handling the comparison operator
	 * @throws ISQLException 
	 */
	public static IComparison buildComparisonOperator(String operator, boolean negated) throws ISQLException
	{
		if(operator.equals("="))
			return negated ? new Different() : new Equal();
		else if(operator.equals("<>"))
			return negated ? new Equal() : new Different();
		else if(operator.equals(">"))
			return negated ? new LessOrEqual() : new Greater();
		else if(operator.equals("<"))
			return negated ? new GreaterOrEqual() : new Less();
		else if(operator.equals(">="))
			return negated ? new Less() : new GreaterOrEqual();
		else if(operator.equals("<="))
			return negated ? new Greater() : new LessOrEqual();
		else
			throw new ISQLException("Cannot recognize the operator "+operator);
	}

}
