/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.builder;

import java.util.Deque;
import java.util.LinkedList;

/**
 * Keeps track of all expressions that are parents or ancestors of the current expression.
 * With it we can check if, for example, the current expression is parameter of a function or
 * it a top level expression in the select part of the query.
 * It is immutable. 
 * @author SHZ Nov 5, 2007
 */
public class ExpressionStack
{
	/**
	 * The real stack
	 */
	Deque<ExpressionBuilderTypes> dqeParents;
	
	public ExpressionStack()
	{
		dqeParents = new LinkedList<ExpressionBuilderTypes>(); 
	}
	
	private ExpressionStack(ExpressionStack toCopy)
	{
		dqeParents = new LinkedList<ExpressionBuilderTypes>(toCopy.dqeParents);
	}
	
	/**
	 * Builds a new stack with the content of this plus the new element
	 * @param toAdd the element to add to the stack
	 * @return the expression stack resulting from the combination of the old one plus the new element
	 */
	public ExpressionStack add(ExpressionBuilderTypes toAdd)
	{
		ExpressionStack newParents = new ExpressionStack(this);
		newParents.dqeParents.add(toAdd);
		return newParents;		
	}
	/**
	 * Checks if one of the ancestors of the current expression
	 * has this type (FUNCTION,..,)
	 * @param parent the type of expression that has to be checked
	 * @return true if the stack contains that expression type
	 */
	public boolean contains(ExpressionBuilderTypes parent)
	{
		return dqeParents.contains(parent);
	}
}
