/*
 * Copyright (C) 2008 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.builder;

import static org.junit.Assert.*;

import java.util.TreeMap;

import isql.ColumnKey;
import isql.ColumnValues;
import isql.IPredicate;
import isql.ISQLException;
import isql.ISQLSelectParser;
import isql.ISQLSelectParserTest;
import isql.array.Array;
import isql.predicate.AndPredicate;

import org.antlr.runtime.RecognitionException;
import org.junit.Test;

/**
 * @author SHZ Oct 14, 2008
 *
 */
public class WhereBuilderTest
{

	/**
	 * Test method for {@link isql.builder.WhereBuilder#build(isql.ISQLSelectParser.ISearchCondition)}.
	 * @throws ISQLException 
	 * @throws RecognitionException 
	 */
	@Test
	public void testBuild() throws ISQLException, RecognitionException
	{
		String sql = "select animals.dog as thedog, animals.cat as thecat"+
			" from [dog, cat, elefant, zebra, kiwi] as animals"+
			" where (animals.elefant <> animals.zebra or animals.kiwi = animals.dog)" +
			" and animals.dog = animals.cat";
		ISQLSelectParser parser = ISQLSelectParserTest.applyQuery(sql);
		WhereBuilder b = new WhereBuilder(new ColumnValues(new TreeMap<ColumnKey, Array>()));
		IPredicate predicate = b.build(parser.getWhere());
		assertTrue(predicate instanceof AndPredicate);
		
		
	}

}
