/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.expression;

import isql.Column;
import isql.ColumnKey;
import isql.ColumnType;
import isql.ISQLException;
import isql.array.Array;
import isql.comparison.Less;
import isql.constant.NumericConstant;
import isql.test.JUnitMatrices;
import isql.util.ArrayBuilder;

import java.util.Arrays;

import org.junit.Test;

/**
 * @author SHZ Nov 7, 2007
 *
 */
public class CaseExpressionTest
{

	/**
	 * Test method for {@link isql.expression.CaseExpression#getResult()}.
	 * @throws ISQLException 
	 */
	@Test
	public void testGetResult() throws ISQLException
	{
		ColumnKey caseColumnKey = new ColumnKey("table", "case");
		Column caseColumn = new Column(caseColumnKey, new Array(ArrayBuilder.convertToBig(ColumnType.NUMERIC, new double[] { 12, 23, 24, 42 }), ColumnType.NUMERIC));
		CaseExpression expression = new CaseExpression(
				caseColumn,
				new ConstantExpression(new NumericConstant(Double.valueOf(40))),
				Arrays.asList(new WhenThen[] {
					new WhenThen(new When(new Less(), new NumericConstant(Double.valueOf(15))), new ConstantExpression(new NumericConstant(Double.valueOf(15)))),
					new WhenThen(new When(new Less(), new NumericConstant(Double.valueOf(30))), new ConstantExpression(new NumericConstant(Double.valueOf(30))))
				})				
				);
		Array res = (Array) expression.getResult();
		JUnitMatrices.assertEquals(res.getArray(), 
				ArrayBuilder.convertToBig(ColumnType.NUMERIC, new double[] { 15, 30, 30, 40}));
	}
	
	
}
