/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.expression;

import isql.ColumnKey;
import isql.ISQLException;
import isql.ITypedValue;
import isql.groupby.Groups;

import java.util.Set;
import java.util.TreeSet;


/**
 * A simple table-column expression. 
 * In this case the SQL query contains a group by claues, so that this expression is repeated
 * for each row in a group. In other words there is only one value of the expression for the
 * whole group
 * @author SHZ Nov 5, 2007
 */
public class ColumnExpressionByGroup implements ISimpleExpression, IWhereExpression
{
	/**
	 * The column key of the column contained in this expression
	 */
	private ColumnKey key;
	/**
	 * All the groups coming from the group by clause
	 */
	private Groups groups;	
	/**
	 * 
	 */
	public ColumnExpressionByGroup(ColumnKey key, Groups groups)
	{
		this.key = key;
		this.groups = groups;
		
	}
	/* (non-Javadoc)
	 * @see isql.IExpression#getResult()
	 */
	public ITypedValue getResult() throws ISQLException
	{
		if(!groups.isGroupByColumnKey(key))
			throw new ISQLException("The column "+key+" is not a group by expression");
		return groups.getGroupByColumnValues(key);
	}
	/* (non-Javadoc)
	 * @see isql.IExpression#getInvolvedColumns()
	 */
	public Set<ColumnKey> getInvolvedColumns()
	{
		Set<ColumnKey> setColumnKey = new TreeSet<ColumnKey>();
		setColumnKey.add(key);
		return setColumnKey;
	}
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return "[COLUMNEXPRESSIONBYGROUP Column: "+key+" Groups: "+groups+"]";
	}
}
