/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.expression;

import isql.ColumnKey;
import isql.IConstant;
import isql.IExpression;
import isql.ISQLException;
import isql.ITypedValue;
import isql.array.Array;
import isql.constant.BooleanConstant;
import isql.constant.DateConstant;
import isql.constant.NumericConstant;
import isql.constant.TextConstant;
import isql.unary.IUnary;

import java.sql.Timestamp;
import java.util.Set;

import isql.ColumnType;

/**
 * To evaluate an expression with an unary operator
 * @author SHZ Oct 16, 2007
 */
public class UnaryExpression implements IExpression
{

	/**
	 * The expression 
	 */
	private IExpression expression;
	/**
	 * The unary operator (minus, not)
	 */	
	private IUnary unary;
	
	public UnaryExpression(IExpression expression, IUnary unary)
	{
		this.expression = expression;
		this.unary = unary;
	}

	/* (non-Javadoc)
	 * @see isql.IExpression#getInvolvedColumns()
	 */
	public Set<ColumnKey> getInvolvedColumns()
	{
		return expression.getInvolvedColumns();
	}

	/* (non-Javadoc)
	 * @see isql.IExpression#getResult()
	 */
	public ITypedValue getResult() throws ISQLException
	{
		ITypedValue valExpression = expression.getResult();
		if(valExpression instanceof Array)
		{
			Array arrayExpression = (Array)valExpression;
			Object[] arrExpression = arrayExpression.getArray();
			Object[] arrResult = new Object[arrExpression.length];
			for(int i = 0; i < arrExpression.length; i++)
			{
				arrResult[i] = unary.apply(arrExpression[i]);
			}
			return new Array(arrResult, arrayExpression.getType());
		}
		else
		{
			IConstant constExpression = (IConstant)valExpression;
			Object res = unary.apply(constExpression.getValueAsObject());
			ColumnType type = constExpression.getType();
			return createConstantOfType(res, type);
			
		}
	}

	private ITypedValue createConstantOfType(Object res, ColumnType type)
			throws AssertionError
	{
		switch(type)
		{
		case NUMERIC:
			return new NumericConstant((Double) res);
		case TEXT:
			return new TextConstant((String) res);
		case DATE:
			return new DateConstant((Timestamp) res);				
		case BOOLEAN:
			return new BooleanConstant((Boolean) res);
		default:
			throw new AssertionError("Type of the constant not recognized: "+type);
		}
	}
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return "[UNARYEXPRESSION "+unary+" "+expression+"]";
	}

}
