/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.expression;

import isql.Column;
import isql.IComparison;
import isql.IConstant;
import isql.ISQLException;
import isql.array.Array;

/**
 * In a case clause, it is the WHEN part of one of the WHEN...THEN clauses.
 * it is in the form: WHEN <operator> <constant>, e.g. WHEN = 10
 * @author SHZ Oct 24, 2007
 */
public class When
{
	/**
	 * The operator that compares the test expression with the constant
	 */
	private IComparison operator;
	/**
	 * The constant with which the expression is compared
	 */
	private IConstant against;
	/**
	 * Constructor
	 * @param operator the operator used in the when
	 * @param against the constant that is compared with the values of the column
	 */
	public When(IComparison operator, IConstant against)
	{
		this.operator = operator;
		this.against = against;
	}
	
	/**
	 * Compares the column values with the given constant using the given operator,
	 * @param test the column to compare
	 * @return a boolean array with one item for each item of the column, 
	 * that tells if that item satisfied the when condition. 
	 * @throws ISQLException
	 */
	public boolean[] apply(Column test) throws ISQLException
	{
		Array array = test.getArray();
		Object[] arrValues = array.getArray();
		int size = array.getSize();
		boolean[] arrRes = new boolean[size];
		for(int i=0; i < size; i++)
		{
			Object testItem = arrValues[i];
			arrRes[i] = operator.compare(testItem, against.getValueAsObject());				
		}		
		return arrRes;
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return "[WHEN "+operator+" "+against+"]";
	}
	
}
