/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.groupby;

import isql.ColumnKey;
import isql.ColumnType;

/**
 * The column key (column+table) and the type of its values
 * @author SHZ Nov 5, 2007
 */
public class ColumnKeyAndType
{
	/**
	 * Identifies totally the column (column name+table)
	 */
	private ColumnKey key;
	/**
	 * The type of the values for this column
	 */
	private ColumnType type;
	/**
	 * @param key
	 * @param type
	 */
	public ColumnKeyAndType(ColumnKey key, ColumnType type)
	{
		this.key = key;
		this.type = type;
	}
	/**
	 * @return the key
	 */
	public ColumnKey getKey()
	{
		return key;
	}
	/**
	 * @return the type
	 */
	public ColumnType getType()
	{
		return type;
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		StringBuilder b = new StringBuilder();
		b.append("[COLUMNKEYANDTYPE");
		b.append(" key: ").append(key.toString());
		b.append(" type: ").append(type.toString());
		b.append(']');
		return b.toString();
	}
	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + ((key == null) ? 0 : key.hashCode());
		result = prime * result + ((type == null) ? 0 : type.hashCode());
		return result;
	}
	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		final ColumnKeyAndType other = (ColumnKeyAndType) obj;
		if (key == null)
		{
			if (other.key != null)
				return false;
		}
		else if (!key.equals(other.key))
			return false;
		if (type == null)
		{
			if (other.type != null)
				return false;
		}
		else if (!type.equals(other.type))
			return false;
		return true;
	}

	
}
