/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.orderby;

import java.util.Arrays;


/**
 * It contains the values of the columns included in the ORDER BY clause for a certain row of the result set.
 * Remember that the same set of values (the same row) can recur more than once in the result set 
 * @author SHZ Nov 1, 2007
 */
public class OrderByKey implements Comparable<OrderByKey>
{
	/**
	 * The values for a row of the result set
	 */
	private Object arrKey[];
	/**
	 * The way in which the rows have to be ordered, defined by the order by clause
	 */
	private OrderByKeyBehaviour behaviour;
	
	public OrderByKey(Object arrKey[], OrderByKeyBehaviour behaviour)
	{
		this.arrKey = arrKey;
		this.behaviour = behaviour;
	}

	/**
	 * We use the behaviour to compare the values of two rows
	 */
	public int compareTo(OrderByKey o)
	{
		return behaviour.compare(this, o);
	}

	/**
	 * The values for a row of the result set
	 * @return the arrKey
	 */
	public Object[] getArrKey()
	{
		return arrKey;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + Arrays.hashCode(arrKey);
		result = prime * result
				+ ((behaviour == null) ? 0 : behaviour.hashCode());
		return result;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		OrderByKey other = (OrderByKey) obj;
		if (!Arrays.equals(arrKey, other.arrKey))
			return false;
		if (behaviour == null)
		{
			if (other.behaviour != null)
				return false;
		}
		else if (!behaviour.equals(other.behaviour))
			return false;
		return true;
	}

}
