/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.orderby;

import java.util.Arrays;

/**
 * Defines how the result set values have to be ordered depending by the
 * columns of the ORDER BY clause
 * @author SHZ Nov 14, 2007
 */
public class OrderByKeyBehaviour
{
	/**
	 * For each order by column tells if the result set has to be ordered by
	 * that column in ascendent or descendent way 
	 */
	private boolean[] arrAscendent;
	
	
	/**
	 * @param arrAscendent for each ORDER BY column, tells if the column has to be
	 * 			ordered ascendently or descendently
	 */
	public OrderByKeyBehaviour(boolean[] arrAscendent)
	{
		this.arrAscendent = arrAscendent;
	}

	
	/**
	 * compares two rows of the result set in the way defined
	 * by the order by clause
	 * @param a the values for the result set's row b
	 * @param b the values for the result set's row b
	 * @return if a < b
	 */
	@SuppressWarnings("unchecked")
	public int compare(OrderByKey a, OrderByKey b)
	{
		// for each element of the row
		for(int i = 0; i < a.getArrKey().length; i++)
		{
			Comparable aI = (Comparable) a.getArrKey()[i];
			Comparable bI = (Comparable) b.getArrKey()[i];
			int resI = aI.compareTo(bI);
			boolean ascendent = arrAscendent[i];
			if(resI != 0)
			{
				if(ascendent)
					return resI;
				else
					return -resI;
			}
		}
		return 0;

	}


	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode()
	{
		final int prime = 31;
		int result = 1;
		result = prime * result + Arrays.hashCode(arrAscendent);
		return result;
	}


	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj)
	{
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		OrderByKeyBehaviour other = (OrderByKeyBehaviour) obj;
		if (!Arrays.equals(arrAscendent, other.arrAscendent))
			return false;
		return true;
	}
	
}
