/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.test;

import org.junit.Assert;

/**
 * JUnit as it is does not have support for vectors and matrices. 
 * This class adds it
 * @author SHZ Nov 8, 2007
 */
public class JUnitMatrices
{
	/**
	 * Checks if two vectors of objects (String, Date, ...) 
	 * are equal
	 * Throws AssertionFailedError with the index of the failed item if not
	 * @param a
	 * @param b
	 */
	public static void assertEquals(Object[] a, Object[] b)
	{
		Assert.assertEquals(a.length , b.length);
		for(int i = 0; i < a.length; i++)
			try
			{
				Assert.assertEquals(a[i], b[i]);
			}
			catch(AssertionError ex)
			{
				throw new AssertionError("["+i+"] "+ex.getMessage());
			}
	}

	/**
	 * Checks if two vectors of doubles are equal
	 * Throws AssertionError with the index of the failed item if not
	 * @param a
	 * @param b
	 */	
	public static void assertEquals(double[] a, double[] b)
	{
		assertEquals(a, b, 0);
	}

	/**
	 * Checks if two vectors of doubles are equal concerning a certain delta
	 * Throws AssertionError with the index of the failed item if not
	 * @param a
	 * @param b
	 */	
	public static void assertEquals(double[] a, double[] b, double delta)
	{
		Assert.assertEquals(a.length , b.length);
		for(int i = 0; i < a.length; i++)
			try
			{
				Assert.assertEquals(a[i], b[i], delta);
			}
			catch(AssertionError ex)
			{
				throw new AssertionError("["+i+"] "+ex.getMessage());
			}
	}
	
	
	/**
	 * Checks if two vectors of booleans 
	 * are equal
	 * Throws AssertionError with the index of the failed item if not
	 * @param a
	 * @param b
	 */		
	public static void assertEquals(boolean[] a, boolean[] b)
	{
		Assert.assertEquals(a.length , b.length);
		for(int i = 0; i < a.length; i++)
			try
			{
				Assert.assertEquals(a[i], b[i]);
			}
			catch(AssertionError ex)
			{
				throw new AssertionError("["+i+"] "+ex.getMessage());
			}
	}

	
	/**
	 * Checks if two matrices of objects 
	 * are equal
	 * Throws AssertionError with the index of the failed item if not
	 * @param a
	 * @param b
	 */		
	public static void assertEquals(Object[][] a, Object[][] b)
	{
		Assert.assertEquals(a.length , b.length);
		for(int i = 0; i < a.length; i++)
			try
			{
				assertEquals(a[i], b[i]);
			}
			catch(AssertionError ex)
			{
				throw new AssertionError("["+i+"]"+ex.getMessage());
			}			
	}

	/**
	 * Checks if two matrices of doubles 
	 * are equal
	 * Throws AssertionError with the index of the failed item if not
	 * @param a
	 * @param b
	 */			
	public static void assertEquals(double[][] a, double[][] b)
	{
		assertEquals(a, b, 0);
	}

	/**
	 * Checks if two matrices of doubles are equal,
	 * concerning a certain delta
	 * @param a
	 * @param b
	 * @param delta
	 */
	public static void assertEquals(double[][] a, double[][] b, double delta)
	{
		Assert.assertEquals(a.length , b.length);
		for(int i = 0; i < a.length; i++)
			try
			{
				assertEquals(a[i], b[i], delta);
			}
			catch(AssertionError ex)
			{
				throw new AssertionError("["+i+"] "+ex.getMessage());
			}
	}
	

	/**
	 * Checks if two matrices of booleans
	 * are equal
	 * Throws AssertionError with the index of the failed item if not
	 * @param a
	 * @param b
	 */			
	public static void assertEquals(boolean[][] a, boolean[][] b)
	{
		Assert.assertEquals(a.length , b.length);
		for(int i = 0; i < a.length; i++)
			try
			{
				assertEquals(a[i], b[i]);
			}
			catch(AssertionError ex)
			{
				throw new AssertionError("["+i+"]"+ex.getMessage());
			}
	}

}
