/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.util;

import java.sql.Timestamp;

import isql.ColumnType;

/**
 * Utility functions for the arrays composing the columns of the SQL query
 * @author SHZ Oct 26, 2007
 */
public class ArrayBuilder
{
	/**
	 * Builds an array of a certain type
	 * @param type the type of the array (NUMERIC, TEXT...)
	 * @param size the size of the array
	 * @return the arrays
	 */
	public static Object[] buildArray(ColumnType type, int size)
	{
		switch(type)
		{
		case NUMERIC:
			return new Double[size];
		case TEXT:
			return new String[size];
		case DATE:
			return new Timestamp[size];
		case BOOLEAN:
			return new Boolean[size];
		default:
			throw new AssertionError("Type not recognized when building an array");
		}
	}
	
	/**
	 * Converts an array of primitives (double, boolean) to an array of objects
	 * (Double, Boolean)
	 * @param type the type of the array (NUMERIC, BOOLEAN...)
	 * @param small the array of primitives
	 * @return the array of objects
	 */
	public static Object[] convertToBig(ColumnType type, Object small)
	{
		switch(type)
		{
		case NUMERIC:
		{
			double[] arrSmall = (double[]) small;
			Double[] arrBig = (Double[]) buildArray(type, arrSmall.length);
			for(int i = 0; i < arrSmall.length; i++)
				arrBig[i] = Double.valueOf(arrSmall[i]);
			return arrBig;
		}		
		case TEXT:
			return (String[])small;
		case DATE:
			return (Timestamp[])small;
		case BOOLEAN:
		{
			boolean[] arrSmall = (boolean[]) small;
			Boolean[] arrBig = (Boolean[]) buildArray(type, arrSmall.length);
			for(int i = 0; i < arrSmall.length; i++)
				arrBig[i] = Boolean.valueOf(arrSmall[i]);
			return arrBig;
		}
		default:
			throw new AssertionError("Type not recognized when building an array");
		}		
	}
	

	/**
	 * Converts an array of int to an array of Integer
	 * @param arrSmall the int[] array
	 * @return the Integer[] array
	 */
	public static Object[] convertToBigInteger(int[] arrSmall)
	{
		Integer[] arrBig = new Integer[arrSmall.length];
		for(int i = 0; i < arrSmall.length; i++)
			arrBig[i] = Integer.valueOf(arrSmall[i]);
		return arrBig;
	}
	
}
