/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */
package isql.util;

import java.util.Map;

/**
 * Utility functions to convert collections to strings (for debug purposes)
 * @author SHZ Dec 11, 2007
 */
public class CollectionsToString
{
	/**
	 * Converts the map to a string of the type [k1->v1],[k2->v2]... where k1..n are the map
	 * keys and v1..vn are the map values
	 * @param <K> the key type
	 * @param <V> the value type
	 * @param map the map to convert
	 * @return the text resulting from the conversion
	 */
	public static <K,V> String mapToString(Map<K, V> map)
	{
		StringJoin join = new StringJoin(',');
		for(Map.Entry<K, V> entry : map.entrySet())
		{
			K key = entry.getKey();
			V value = entry.getValue();
			join.add("["+key+"->"+value+"]");
		}
		return join.toString();
	}
}
