/*
 * Copyright (C) 2007 Andrea Ferrandi <aferrandi@users.sourceforge.net>. 
 * Released under the terms of the GNU LGPL v3.0.
 */

package isql.util;

import java.util.Collection;

/**
 * Joins texts using a separator (comma...)
 * @author SHZ Jun 22, 2007
 */
public class StringJoin
{
	/**
	 * The buffer that accumulates the joined strings
	 */
	StringBuilder builder = new StringBuilder();
	/**
	 * The separator (comma, semicolon...)
	 */
	public char separator;
	/**
	 * If it is the first element, don't precede it with the separator 
	 */
	public boolean first = true;
	/**
	 * The constructor
	 * @param separator the separator (generally a comma or a semicolon)
	 */
	public StringJoin(char separator)
	{
		this.separator = separator;
	}
	
	/**
	 * adds a value to the final text
	 * @param <T> the type of the value to add
	 * @param toAdd the value to add to the join
	 */
	public <T> void add(T toAdd)
	{
		if(!first)
			builder.append(',');
		else
			first = false;
		builder.append(toAdd);
	}

	/**
	 * adds an array of values to the final text
	 * @param <T> the type of the values to add
	 * @param arrToAdd the values to add to the join
	 */	
	public <T> void add(T[] arrToAdd)
	{
		for(T text : arrToAdd)
			add(text.toString());
	}
	/**
	 * adds a collection of values to the final text
	 * @param <T> the type of the values to add
	 * @param lstToAdd the values to add to the join
	 */
	public <T> void add(Collection<T> lstToAdd)
	{
		for(T obj : lstToAdd)
			add(obj);
	}

	/**
	 * builds a text joining an array of values with a separator
	 * @param <T> the type of the values to join
	 * @param arrToAdd the values to join
	 * @param separator the separator
	 * @return the final text 
	 */	
	public static <T> String join(T[] arrToAdd, char separator)
	{
		StringJoin joiner = new StringJoin(separator);
		joiner.add(arrToAdd);
		return joiner.toString();
	}

	/**
	 * builds a text joining a collection of values with a separator
	 * @param <T> the type of the values to join
	 * @param lstToAdd the values to join
	 * @param separator the separator
	 * @return the final text 
	 */		
	public static <T> String join(Collection<T> lstToAdd, char separator)
	{
		StringJoin joiner = new StringJoin(separator);
		joiner.add(lstToAdd);
		return joiner.toString();
	}
	
	
	@Override
	public String toString()
	{
		return builder.toString();
	}
}
